==> nextcloud-25.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/zh_CN.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "圈子",
    "Circles' files" : "圈子的文件",
    "Select circles to filter by" : "选择圈子来筛选",
    "No circles found" : "未找到任何圈子",
    "Please select circles to filter by" : "请选择圈子来筛选",
    "No files found for the selected circles" : "该圈子下没有任何文件",
    "You created the circle {circle}" : "您创建了圈子 {circle}",
    "{author} created the circle {circle}" : "{author} 创建了圈子 {circle}",
    "You deleted {circle}" : "您删除了 {circle}",
    "{author} deleted {circle}" : "{author} 已删除 {circle}",
    "You linked {group} to {circle}" : "您已将 {group} 链接到 {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} 已将 {group} 连接到 {circle}",
    "You unlinked {group} from {circle}" : "您已将 {group} 从 {circle} 中断开",
    "{group} has been unlinked from {circle} by {author}" : "{author} 已将 {group} 从 {circle} 中断开",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "您已将 {circle} 中的组  {group} 的级别修改为 %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} 已将 {circle} 中的组 {group} 的级别修改为 %1$s",
    "You sent a request to link {circle} with {remote}" : "您发送了一个请求，将 {circle} 与 {remote} 链接",
    "{author} sent a request to link {circle} with {remote}" : "{author} 发送了一个请求，将 {circle} 与 {remote} 链接",
    "{remote} requested a link with {circle}" : "{remote} 要求与 {circle} 链接",
    "The request to link {circle} with {remote} has been rejected" : "将 {circle} 与 {remote} 链接的请求已被拒绝",
    "The request to link {remote} with {circle} has been canceled remotely" : "将 {remote} 与 {circle} 链接的请求已被远程取消",
    "The request to link {circle} with {remote} has been accepted" : "{circle} 与 {remote} 链接的请求已被接受",
    "You dismissed the request to link {remote} with {circle}" : "您已将 {remote} 与 {circle} 链接的请求撤销",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} 驳回了将 {remote} 与 {circle} 链接的请求",
    "You canceled the request to link {circle} with {remote}" : "您取消了将 {circle} 与 {remote} 链接的请求",
    "{author} canceled the request to link {circle} with {remote}" : "{author} 取消了将 {circle} 与 {remote} 链接的请求",
    "You accepted the request to link {remote} with {circle}" : "接受了 {remote} 与 {circle} 链接的请求",
    "{author} accepted the request to link {remote} with {circle}" : "{author} 接受了 {remote} 与 {circle} 链接的请求",
    "A link between {circle} and {remote} is now up and running" : "{circle} 和 {remote} 之间的链接现已启动并运行",
    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} 和 {remote} 之间的链接已被远程关闭",
    "You closed the link between {circle} and {remote}" : "您关闭了 {circle} 和 {remote} 之间的链接",
    "{author} closed the link between {circle} and {remote}" : "{author} 关闭了 {circle} 和 {remote} 之间的链接",
    "You joined {circle}" : "您已经加入了 {circle}",
    "{member} joined {circle}" : "{member} 加入了 {circle}",
    "You accepted the invitation to join {circle}" : "您接受邀请加入 {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} 接受邀请加入 {circle}",
    "You added {member} as member to {circle}" : "您已将 {member} 加入 {circle}",
    "You have been added as member to {circle} by {author}" : "您已被 {author} 添加为 {circle} 的成员",
    "{member} has been added as member to {circle} by {author}" : "{member} 已被 {author} 添加为 {circle} 的成员",
    "You added {external} to {circle}" : "您已将 {external} 添加到 {circle}",
    "{external} has been added to {circle} by {author}" : "{external} 已由 {author} 添加到 {circle}",
    "You accepted {member}'s request to join {circle}" : "您接受 {member} 的请求加入 {circle}",
    "Your request to join {circle} has been accepted by {author}" : "您加入 {circle} 的请求已被 {author} 接受",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} 加入 {circle} 的请求已被 {author} 允许",
    "You left {circle}" : "您离开了 {circle}",
    "{member} left {circle}" : "{member} 离开了 {circle}",
    "You declined the invitation to join {circle}" : "您拒绝了加入 {circle} 的邀请",
    "{member} declined an invitation to join {circle}" : "{member} 拒绝加入 {circle}",
    "You cancelled your request to join {circle}" : "您取消了加入 {circle} 的请求",
    "{member} cancelled his request to join {circle}" : "{member} 取消了他加入 {circle} 的请求",
    "You removed {member} from {circle}" : "您已从 {circle} 删除 {member}",
    "You have been removed from {circle} by {author}" : "您已被 {author} 移出 {circle}",
    "{member} has been removed from {circle} by {author}" : "{member} 已被 {author} 从 {circle} 移除",
    "You removed {external} from {circle}" : "您已从 {circle} 移除了 {external}",
    "{external} has been removed from {circle} by {author}" : "{external} 已由 {author} 从 {circle} 移除",
    "You cancelled {member}'s invitation to join {circle}" : "您已取消 {member} 加入 {circle} 的邀请",
    "Your invitation to join {circle} has been cancelled by {author}" : "您加入 {circle} 的邀请已被 {author} 取消",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 已取消 {member} 加入 {circle} 的邀请",
    "You dismissed {member}'s request to join {circle}" : "您已经 {member} 的请求加入 {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "您加入 {circle} 的请求已被 {author} 驳回",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} 加入 {circle} 的请求已被 {author} 驳回",
    "You invited {member} to join {circle}" : "您邀请 {member} 加入 {circle}",
    "You have been invited to join {circle} by {author}" : "{author} 邀请您加入 {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} 已被 {author} 邀请参加 {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "您将 {circle} 中的 {member} 的级别更改为 %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} 将 {circle} 的级别更改为 %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 将 {circle} 的 {member} 的级别更改为 %1$s",
    "You sent a request to join {circle}" : "您发送了加入 {circle} 的请求",
    "{member} sent a request to join {circle}" : "{member} 发送了加入 {circle} 的请求",
    "You are the new owner of {circle}" : "您是 {circle} 的新拥有者",
    "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新拥有者",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "当出现发生在一个您是其中一员的<strong>圈子</strong>的事件时",
    "Any important event in a <strong>Circle</strong> you are moderating" : "您正在<strong>圈子</strong>中主持的任何重要事件",
    "On global events happening in any <strong>Circle</strong>" : "当出现发生在任意<strong>圈子</strong>中的全局事件时",
    "Single" : "单个",
    "Personal" : "个人",
    "System" : "系统",
    "Visible" : "可见的",
    "Open" : "打开",
    "Invite" : "邀请",
    "Join Request" : "加入邀请",
    "Friends" : "好友",
    "Password Protected" : "受密码保护",
    "No Owner" : "无所有人",
    "Hidden" : "隐藏的",
    "Backend" : "后端",
    "Local" : "本地",
    "Root" : "根路径",
    "Circle Invite" : "Circle 邀请",
    "Federated" : "联合的",
    "Mount point" : "挂载点",
    "Nextcloud Group" : "NextCloud 群组",
    "Email Address" : "电子邮件地址",
    "Contact" : "联系",
    "Circle" : "圈子",
    "Nextcloud App" : "NextCloud 应用",
    "Member" : "成员",
    "Moderator" : "主持人",
    "Admin" : "管理员",
    "Owner" : "所有者",
    "%s shared »%s« with you." : "%s 已共享 »%s« 给您。",
    "%s shared »%s« with \"%s\"." : "%s 将 »%s« 和\"%s\" 共享",
    "%s on %s" : "%s上%s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 和你分享了 »%2$s«\n你应该已经收到一封单独的电子邮件，上面有一个访问链接。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s 和你分享了 »%2$s« 你应该已经收到一封单独的电子邮件，上面有一个访问链接。",
    "Password to access »%1$s« shared to you by %2$s" : "用于访问 %2$s 共享给您的 »%1$s« 的密码",
    "Password to access »%s«" : "访问 »%s« 的密码",
    "It is protected with the following password:" : "其已被以下密码保护：",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "Click the button below to open it." : "点击下面的按钮打开它。",
    "Open »%s«" : "打开 »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s 和你分享了多个文件\n你应该已经收到一封单独的电子邮件，上面有访问它们的链接\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s 和你分享了多个文件。你应该已经收到一封单独的电子邮件，上面有访问它们的链接",
    "Password to access files shared to you by %1$s" : "使用密码访问由 %1$s 共享给您的文件",
    "Password to access files" : "用以访问文件的密码",
    "%s shared multiple files with \"%s\"." : "%s 将多个文件和 \"%s\" 进行了分享",
    "%s shared multiple files with you." : "%s 对您共享了多个文件。",
    "Boot up" : "启动",
    "Initialisation Nextcloud" : "初始化 Nextcloud",
    "Initialisation Circles App" : "初始化 Circles 应用",
    "Fresh installation status" : "全新安装状态",
    "Building Local Database" : "正在构建本地数据库",
    "Testing Basic Circle Creation" : "正在测试基础 Circle 创建",
    "Adding local users and moderators" : "添加本地用户和管理员",
    "Circle not found" : "查找不到圈子",
    "Circle not found " : "找不到圈子",
    "A circle with that name exists" : "存在具有该名称的圈子",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "您的管理员至少允许一种类型的圈子，否则您不能使用“圈子”应用程序",
    "This member does not exist" : "此成员不存在",
    "Federated link not found" : "未找到联合云链接",
    "This feature is not available for personal circles" : "此功能不适用于个人圈子",
    "The circle is not federated" : "圈子没有联合",
    "You cannot join this circle" : "您不能加入此圈子",
    "This member is not a moderator" : "此成员不是管理员",
    "Insufficient privileges" : "权限不足",
    "This member is the owner of the circle" : "此成员是圈子的所有者",
    "Level cannot be changed for this type of member" : "对于该类型的成员，级别不能被更改",
    "You are already a member of this circle" : "您已经是此圈子的成员",
    "You have been blocked from this circle" : "您被限制加入此圈子",
    "You are now a member of the Circle \"%2$s\"" : "您现在是\"%2$s\" 圈子的一员了",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s 已邀请您加入圈子 \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s发送了一条加入\"%2$s\" 圈子的请求",
    "Accept" : "接受",
    "Refuse" : "拒绝",
    "Leave the circle" : "离开圈子",
    "%s" : "%s",
    "Personal Circle" : "个人圈子",
    "%s owned by %s" : "%s 所有者为 %s",
    "You need a specify a type of circle" : "您需要指定一种类型的圈子",
    "This member is not the owner of the circle" : "此成员不是圈子的所有者",
    "This member is not an admin of the circle" : "该成员不是此圈子的管理员",
    "Group contains too many members" : "群组包含太多成员",
    "This group does not exist" : "该分组不存在",
    "This group is already linked to the circle" : "该分组已经链接到该圈子",
    "You cannot edit level in a personal circle" : "您无法编辑个人圈子中的级别",
    "Group cannot be set as owner of a circle" : "组不能设置为圈子的所有者",
    "now" : "现在",
    "Email format is not valid" : "电子邮件格式无效",
    "This contact is not available" : "此联系人不可用",
    "%s shared a file with \"%s\"." : "%s 和 \"%s\"分享了一个文件",
    "%s shared a file with you." : "%s 和你分享了一个文件",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s和你分享了一些内容。\n你应该已经收到了一封带访问链接的邮件。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 和你分享了一些内容。你应该已经收到了一封带访问链接的邮件",
    "Password to access content" : "内容访问密码",
    "This item is already shared with this circle" : "这个项目已经分享给这个圈子了",
    "Could not find share" : "查找不到共享",
    "Bring cloud-users closer together." : "把云端用户连接到一起。",
    "No files in here" : "此处没有文件",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Nextcloud User" : "NextCloud 用户",
    "This user is already a member of the circle" : "此用户已经是圈子的成员",
    "The user is already a member of this circle" : "此用户已经是此圈子的成员",
    "The user has already been invited into this circle" : "用户已被邀请进入此圈子",
    "This user does not exist" : "此用户不存在",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Circles 允许你的用户创建自己的用户/同事/好友组。\n这些用户群(或“圈子”)可以被其他应用程序用于共享目的。"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/zh_CN.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "你创建了团队 {circle}",
    "{author} created the team {circle}" : "{author} 创建了团队 {circle}",
    "You deleted {circle}" : "您删除了 {circle}",
    "{author} deleted {circle}" : "{author} 已删除 {circle}",
    "You made {member} join {circle}" : "你让 {member} 加入了 {circle}",
    "{author} made {member} join {circle}" : "{author} 让 {member} 加入了 {circle}",
    "You added team {member} as member to {circle}" : "你将团队 {member} 添加至 {circle} 团队",
    "{author} added team {member} as member to {circle}" : "{author}将团队{member}添加至团队{circle}",
    "You made {member} leave {circle}" : "你让 {member} 离开了 {circle}",
    "{author} made {member} leave {circle}" : "{author} 让 {member} 离开了 {circle}",
    "You removed {member} from {circle}" : "您已从 {circle} 删除 {member}",
    "{author} removed {member} from {circle}" : "{author}从{circle}移除了{member}",
    "You joined {circle}" : "您已经加入了 {circle}",
    "{member} joined {circle}" : "{member} 加入了 {circle}",
    "You accepted the invitation to join {circle}" : "您接受邀请加入 {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} 接受邀请加入 {circle}",
    "You added {member} as member to {circle}" : "您已将 {member} 加入 {circle}",
    "You have been added as member to {circle} by {author}" : "您已被 {author} 添加为 {circle} 的成员",
    "{member} has been added as member to {circle} by {author}" : "{member} 已被 {author} 添加为 {circle} 的成员",
    "You added {external} to {circle}" : "您已将 {external} 添加到 {circle}",
    "{external} has been added to {circle} by {author}" : "{external} 已由 {author} 添加到 {circle}",
    "You accepted {member}'s request to join {circle}" : "您接受 {member} 的请求加入 {circle}",
    "Your request to join {circle} has been accepted by {author}" : "您加入 {circle} 的请求已被 {author} 接受",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} 加入 {circle} 的请求已被 {author} 允许",
    "You left {circle}" : "您离开了 {circle}",
    "{member} left {circle}" : "{member} 离开了 {circle}",
    "You declined the invitation to join {circle}" : "您拒绝了加入 {circle} 的邀请",
    "{member} declined an invitation to join {circle}" : "{member} 拒绝加入 {circle}",
    "You cancelled your request to join {circle}" : "您取消了加入 {circle} 的请求",
    "{member} cancelled a request to join {circle}" : "{member} 取消了加入 {circle} 的请求",
    "You have been removed from {circle} by {author}" : "您已被 {author} 移出 {circle}",
    "{member} has been removed from {circle} by {author}" : "{member} 已被 {author} 从 {circle} 移除",
    "You removed {external} from {circle}" : "您已从 {circle} 移除了 {external}",
    "{external} has been removed from {circle} by {author}" : "{external} 已由 {author} 从 {circle} 移除",
    "You cancelled {member}'s invitation to join {circle}" : "您已取消 {member} 加入 {circle} 的邀请",
    "Your invitation to join {circle} has been cancelled by {author}" : "您加入 {circle} 的邀请已被 {author} 取消",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 已取消 {member} 加入 {circle} 的邀请",
    "You dismissed {member}'s request to join {circle}" : "您已经 {member} 的请求加入 {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "您加入 {circle} 的请求已被 {author} 驳回",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} 加入 {circle} 的请求已被 {author} 驳回",
    "You invited {member} to join {circle}" : "您邀请 {member} 加入 {circle}",
    "You have been invited to join {circle} by {author}" : "{author} 邀请您加入 {circle}",
    "{member} has been invited to join {circle} by {author}" : "{member} 已被 {author} 邀请参加 {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "您将 {circle} 中的 {member} 的级别更改为 %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} 将 {circle} 的级别更改为 %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 将 {circle} 的 {member} 的级别更改为 %1$s",
    "You sent a request to join {circle}" : "您发送了加入 {circle} 的请求",
    "{member} sent a request to join {circle}" : "{member} 发送了加入 {circle} 的请求",
    "You are the new owner of {circle}" : "你是 {circle} 的新所有者",
    "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新所有者",
    "Teams" : "团队",
    "On events happening in a <strong>team</strong> of which you are a member" : "当你所属的<strong>团队</strong>产生事件时",
    "Any important event in a <strong>team</strong> you are moderating" : "当你所管理的<strong>团队</strong>产生重要事件时",
    "On global events happening in any <strong>team</strong>" : "当所有<strong>团队</strong>产生事件时",
    "Single" : "单个",
    "Personal" : "个人",
    "System" : "系统",
    "Visible" : "可见的",
    "Open" : "打开",
    "Invite" : "邀请",
    "Join request" : "加入请求",
    "Friends" : "好友",
    "Password protected" : "受密码保护",
    "No Owner" : "无所有人",
    "Hidden" : "隐藏的",
    "Backend" : "后端",
    "Local" : "本地",
    "Root" : "根路径",
    "Team invite" : "团队邀请",
    "Federated" : "联合云",
    "Mount point" : "挂载点",
    "Nextcloud Account" : "Nextcloud 账号",
    "Nextcloud Group" : "NextCloud 群组",
    "Email address" : "电子邮件地址",
    "Contact" : "联系",
    "Team" : "团队",
    "Nextcloud App" : "NextCloud 应用",
    "Teams App" : "团队应用",
    "Admin Command Line" : "管理员命令行",
    "Member" : "成员",
    "Moderator" : "主持人",
    "Admin" : "管理员",
    "Owner" : "所有者",
    "%s shared »%s« with you." : "%s 已共享 »%s« 给您。",
    "%s shared »%s« with \"%s\"." : "%s 将 »%s« 和\"%s\" 共享",
    "%s on %s" : "%s上%s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s 和你分享了 »%2$s«\n你应该已经收到一封单独的电子邮件，上面有一个访问链接。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s 和你分享了 »%2$s« 你应该已经收到一封单独的电子邮件，上面有一个访问链接。",
    "Password to access »%1$s« shared to you by %2$s" : "访问 »%1$s« 的密码通过 %2$s 共享给你",
    "Password to access »%s«" : "访问 »%s« 的密码",
    "It is protected with the following password:" : "其已被以下密码保护：",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "Click the button below to open it." : "点击下面的按钮打开它。",
    "Open »%s«" : "打开 »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s 和你分享了多个文件\n你应该已经收到一封单独的电子邮件，上面有访问它们的链接\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s 和你分享了多个文件。你应该已经收到一封单独的电子邮件，上面有访问它们的链接",
    "Password to access files shared to you by %1$s" : "使用密码访问 %1$s 共享给你的文件",
    "Password to access files" : "用以访问文件的密码",
    "%s shared multiple files with \"%s\"." : "%s 将多个文件和 \"%s\" 进行了分享",
    "%s shared multiple files with you." : "%s 对您共享了多个文件。",
    "Boot up" : "启动",
    "Nextcloud Initialization" : "Nextcloud初始化",
    "Circles App Initialization" : "应用程序Circles初始化",
    "Fresh installation status" : "全新安装状态",
    "Building Local Database" : "正在构建本地数据库",
    "Testing Basic Team Creation" : "测试基本团队创建",
    "Adding local users and moderators" : "添加本地用户和管理员",
    "Show all teams" : "显示所有团队",
    "Create a new team" : "创建一个新的团队",
    "Files" : "文件",
    "This feature is not available for personal teams" : "此功能不适用于个人团队",
    "The team is not federated" : "团队没有加入联合云",
    "You cannot join this team" : "你无法加入该团队",
    "This member is not a moderator" : "此成员不是管理员",
    "Insufficient privileges" : "权限不足",
    "This member does not exist" : "此成员不存在",
    "This member is the owner of the team" : "此成员是团队所有者",
    "Level cannot be changed for this type of member" : "对于该类型的成员，级别不能被更改",
    "You are already a member of this team" : "您已经是此团队的成员",
    "You have been blocked from this team" : "您已被阻止加入此团队",
    "The account is already a member of this team" : "该账号已经是此团队的成员",
    "The account has already been invited into this team" : "该账号已被邀请加入此团队",
    "%s (Team owned by %s)" : "%s（%s所拥有）",
    "You are now a member of the Team \"%2$s\"" : "你现在是团队“%2$s”的一员",
    "You have been invited by %1$s into the Team \"%2$s\"" : "你已被 %1$s 邀请至团队 “%2$s”",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s 发送一条加入团队 “%2$s” 的申请",
    "Accept" : "接受",
    "Refuse" : "拒绝",
    "Leave the team" : "离开团队",
    "%s" : "%s",
    "Personal team" : "个人团队",
    "%s owned by %s" : "%s 所有者为 %s",
    "You have no permission to create a new team" : "你没有足够的权限创建一个新的团队",
    "%s shared a file with \"%s\"." : "%s 和 \"%s\"分享了一个文件",
    "%s shared a file with you." : "%s 和你分享了一个文件",
    "%1$s shared %2$s with %3$s" : "%1$s 与 %3$s 共享了 %2$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s 与“%3$s”共享了 %2$s",
    "Open %s" : "打开 %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s和你分享了一些内容。\n你应该已经收到了一封带访问链接的邮件。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 和你分享了一些内容。你应该已经收到了一封带访问链接的邮件",
    "Password to access content shared with you by %1$s" : "用于获取%1$s分享给您内容的密码",
    "Password to access content" : "内容访问密码",
    "This item is already shared with this team" : "该项目已分享至该团队",
    "Bring cloud-users closer together." : "把云端用户连接到一起。",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "团队允许用户创建属于他们自己同事/朋友的群组。\n其他应用可以通过这些群组进行批量共享。",
    "Failed to load teams" : "无法加载团队",
    "Try again" : "请重试",
    "No teams found" : "未找到任何团队",
    "Join or create teams to see them here." : "加入或创建团队即可在此处查看。",
    "Create your first team" : "创建您的第一个团队",
    "Loading…" : "正在加载 ...",
    "More teams" : "更多团队",
    "No files in here" : "此处没有文件",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Shared to Circles" : "共享圈子的文件"
},
"nplurals=1; plural=0;");
